.. _installation:

Installation
============

The sushy-tools Python package can be downloaded and installed with *pip*:

.. code-block:: bash

   $ pip install sushy-tools

Or, if you have virtualenvwrapper installed:

.. code-block:: bash

   $ mkvirtualenv sushy-tools
   $ pip install sushy-tools
